@@ -19,7 +19,7 @@ from ..cl_template import TemplateFormat
 
 
 class objShare(TemplateFormat):
-    """Общий клас для объектов, наследуем
+    """Общий класс для объектов, наследуем
     """
     docObj = None
     reComment = None
